namespace nrdkwebsite;

public static class API
{
    public static async Task<User> PostNewUser(NewUser newuser, DatabaseHandler db)
    {
        User user = new User(newuser.nickname, db.users.OrderBy(p => p.id).Last().id + 1, newuser.mast);
        await db.users.AddAsync(user);
        await db.SaveChangesAsync();
        return user;
    }
    public static async Task<IResult> DeleteUser(int id, DatabaseHandler db)
    {
        User? user = db.users.FirstOrDefault(u => u.id == id);
        if (user == null) return Results.NotFound(new { message = "Пользователь не найден" });
        db.users.Remove(user);
        await db.SaveChangesAsync();
        return Results.Json(user);
    }
    public static IResult GetUserByName(string name, DatabaseHandler db)
    {
        var users = db.users.ToList();
        User? user = users.FirstOrDefault(u => u.nickname == name);
        // если не найден, отправляем статусный код и сообщение об ошибке
        if (user == null) return Results.NotFound(new { message = "Пользователь не найден" });

        // если пользователь найден, отправляем его
        return Results.Json(user);
    }
    public static IResult GetUserById(int id, DatabaseHandler db)
    {
        var users = db.users.ToList();
        User? user = users.FirstOrDefault(u => u.id == id);
        // если не найден, отправляем статусный код и сообщение об ошибке
        if (user == null) return Results.NotFound(new { message = "Пользователь не найден" });

        // если пользователь найден, отправляем его
        return Results.Json(user);
    }
    public static List<User> GetUsers(DatabaseHandler db)
    {
        return db.users.OrderBy(u => u.id).ToList();
    }

}